abacusai.llm_execution_result — AbacusAI documentation

# `abacusai.llm_execution_result`

## Module Contents

### Classes

`LlmExecutionResult` | Results of executing queries using LLM.

class abacusai.llm_execution_result.LlmExecutionResult(client, status=None, error=None, execution={}, preview={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Results of executing queries using LLM.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - status (str) – The status of the execution.

    - error (str) – The error message if the execution failed.

    - execution (ExecuteFeatureGroupOperation) – Information on execution of the query.

    - preview (LlmExecutionPreview) – Preview of executing queries using LLM.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict